package com.aucma.dms.controller;

import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.core.page.TableDataInfo;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.dms.domain.DmsBillsLubeInstanceActivity;
import com.aucma.dms.service.IDmsBillsLubeInstanceActivityService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;




/**
 * 润滑工单实例节点Controller
 *
 * @author Open Platform
 * @date 2024-02-26
 */
@RestController
@RequestMapping("/dms/dmsBillsLubeInstanceActivity")
public class DmsBillsLubeInstanceActivityController extends BaseController
{
    @Autowired
    private IDmsBillsLubeInstanceActivityService dmsBillsLubeInstanceActivityService;

    /**
     * 查询润滑工单实例节点列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsBillsLubeInstanceActivity:list')" )
    @GetMapping("/list")
    public TableDataInfo list(DmsBillsLubeInstanceActivity dmsBillsLubeInstanceActivity)
    {
        startPage();
        List<DmsBillsLubeInstanceActivity> list = dmsBillsLubeInstanceActivityService.selectDmsBillsLubeInstanceActivityList(dmsBillsLubeInstanceActivity);
        return getDataTable(list);
    }

    /**
     * 导出润滑工单实例节点列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsBillsLubeInstanceActivity:export')" )
    ////@Log(title = "润滑工单实例节点", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBillsLubeInstanceActivity dmsBillsLubeInstanceActivity)
    {
        List<DmsBillsLubeInstanceActivity> list = dmsBillsLubeInstanceActivityService.selectDmsBillsLubeInstanceActivityList(dmsBillsLubeInstanceActivity);
        ExcelUtil<DmsBillsLubeInstanceActivity> util = new ExcelUtil<DmsBillsLubeInstanceActivity>(DmsBillsLubeInstanceActivity.class);
        util.exportExcel(response, list, "润滑工单实例节点数据");
    }

    /**
     * 获取润滑工单实例节点详细信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsBillsLubeInstanceActivity:query')" )
    @GetMapping(value = "/{instanceActivityId}")
    public AjaxResult getInfo(@PathVariable("instanceActivityId") Long instanceActivityId)
    {
        return success(dmsBillsLubeInstanceActivityService.selectDmsBillsLubeInstanceActivityByInstanceActivityId(instanceActivityId));
    }

    /**
     * 新增润滑工单实例节点
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsBillsLubeInstanceActivity:add')" )
    ////@Log(title = "润滑工单实例节点", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBillsLubeInstanceActivity dmsBillsLubeInstanceActivity)
    {
        return toAjax(dmsBillsLubeInstanceActivityService.insertDmsBillsLubeInstanceActivity(dmsBillsLubeInstanceActivity));
    }

    /**
     * 修改润滑工单实例节点
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsBillsLubeInstanceActivity:edit')" )
    ////@Log(title = "润滑工单实例节点", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBillsLubeInstanceActivity dmsBillsLubeInstanceActivity)
    {
        return toAjax(dmsBillsLubeInstanceActivityService.updateDmsBillsLubeInstanceActivity(dmsBillsLubeInstanceActivity));
    }

    /**
     * 删除润滑工单实例节点
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsBillsLubeInstanceActivity:remove')" )
    ////@Log(title = "润滑工单实例节点", businessType = BusinessType.DELETE)
	@DeleteMapping("/{instanceActivityIds}")
    public AjaxResult remove(@PathVariable Long[] instanceActivityIds)
    {
        return toAjax(dmsBillsLubeInstanceActivityService.deleteDmsBillsLubeInstanceActivityByInstanceActivityIds(instanceActivityIds));
    }
    @GetMapping("/selectUserIdByDmsBillsLubeInstanceActivityId/{instanceActivityId}/userId/{userId}")
    public boolean selectUserIdByDmsBillsLubeInstanceActivityId(@PathVariable("instanceActivityId") Long inspectInstanceId,@PathVariable("userId") Long userId){
      return   dmsBillsLubeInstanceActivityService.selectUserIdByDmsBillsLubeInstanceActivityId(inspectInstanceId,userId);
    }
}
